# Copyright 1999-2011 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

EAPI=2

inherit autotools eutils

MY_P="${PN}-2.7"

DESCRIPTION="A cross-platform open source C and C++ SDK to ease the development of SOAP/XML Web services"
HOMEPAGE="http://gsoap2.sourceforge.net"
SRC_URI="mirror://sourceforge/gsoap2/gsoap_${PV}.tar.gz"

LICENSE="GPL-2 gSOAP"
SLOT="0"
KEYWORDS="~amd64 ~x86"
IUSE="doc debug examples +ssl static-libs"

DEPEND="sys-devel/flex
	sys-devel/bison
	sys-libs/zlib
	ssl? ( dev-libs/openssl )"
RDEPEND=""

S="${WORKDIR}/${MY_P}"

src_prepare() {



	# Fix Pre-ISO headers
	#epatch "${FILESDIR}/gsoap-2.7-fix-pre-iso-headers.patch"

	# causes compilation of app-emulation/virtualbox-ose[vboxwebsrv] to
	# break (bug #320901):
	#epatch "${FILESDIR}/${PN}-2.7.15-use_libtool.patch"
	epatch "${FILESDIR}/2.7.9/autotools_update-2.7.9k.patch"
	epatch "${FILESDIR}/2.7.9/import_dom_h-2.7.9l.patch"
	epatch "${FILESDIR}/2.7.9/makefile_defines-2.7.9k.patch"
	epatch "${FILESDIR}/2.7.9/gsoap-2.7-fedora-openssl.patch"
	
	rm soapcpp2/stdsoap2_cpp.cpp


	eautoreconf
}

src_configure() {
	econf --enable-shared \
		$(use_enable ssl) \
		$(use_enable examples samples) \
		$(use_enable debug) \
		$(use_enable static-libs static)
}

src_compile() {
	emake -j1 || die "emake failed"
}

src_install() {
	emake DESTDIR="${D}" install || die "Install failed"

	# yes, we also install the license-file since
	# it contains info about how to apply the licenses
	dodoc *.txt

	dohtml changelog.html

	rm -rf "${D}"/usr/lib*/*.la

	if use examples; then
		rm -rf gsoap/samples/Makefile* gsoap/samples/*/Makefile* gsoap/samples/*/*.o
		insinto /usr/share/doc/${PF}/examples
		doins -r gsoap/samples/*
	fi

	if use doc; then
		dohtml -r gsoap/doc/*
	fi

	# Install the core files for some packages that are using these files.
	# this is to work around provided gsoap in many packages (ifolder3, ...)
	insinto /usr/include/gsoap
	doins soapcpp2/*.c*
}
